@@ -38,30 +38,37 @@ class PaymeWebhook(View):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
-        # Try to get the account model from settings
-        # Get the account model from settings
-        account_model_path = getattr(
-            settings, 'PAYME_ACCOUNT_MODEL', 'django.contrib.auth.models.User'
+        paytechuz_settings = getattr(settings, 'PAYTECHUZ', {})
+        payme_settings = paytechuz_settings.get('PAYME', {})
+
+        self.payme_id = payme_settings.get('PAYME_ID') or getattr(settings, 'PAYME_ID', '')
+        self.payme_key = payme_settings.get('PAYME_KEY') or getattr(settings, 'PAYME_KEY', '')
+
+        account_model_path = (
+            payme_settings.get('ACCOUNT_MODEL') or 
+            getattr(settings, 'PAYME_ACCOUNT_MODEL', 'django.contrib.auth.models.User')
         )
         try:
             self.account_model = import_string(account_model_path)
         except ImportError:
-            # If the model is not found, log an error and raise an exception
             logger.error(
-                "Could not import %s. Check PAYME_ACCOUNT_MODEL setting.",
+                "Could not import %s. Check PAYTECHUZ.PAYME.ACCOUNT_MODEL setting.",
                 account_model_path
             )
-            raise ImportError(
-                f"Import error: {account_model_path}"
-            ) from None
+            raise ImportError(f"Import error: {account_model_path}") from None
 
-        self.account_field = getattr(settings, 'PAYME_ACCOUNT_FIELD', 'id')
-        self.amount_field = getattr(settings, 'PAYME_AMOUNT_FIELD', 'amount')
-        self.one_time_payment = getattr(
-            settings, 'PAYME_ONE_TIME_PAYMENT', True
+        self.account_field = (
+            payme_settings.get('ACCOUNT_FIELD') or 
+            getattr(settings, 'PAYME_ACCOUNT_FIELD', 'id')
+        )
+        self.amount_field = (
+            payme_settings.get('AMOUNT_FIELD') or 
+            getattr(settings, 'PAYME_AMOUNT_FIELD', 'amount')
+        )
+        self.one_time_payment = (
+            payme_settings.get('ONE_TIME_PAYMENT') or 
+            getattr(settings, 'PAYME_ONE_TIME_PAYMENT', True)
         )
-        self.payme_id = getattr(settings, 'PAYME_ID', '')
-        self.payme_key = getattr(settings, 'PAYME_KEY', '')
 
     def post(self, request, **_):
         """
@@ -432,8 +439,12 @@ class PaymeWebhook(View):
             # If transaction is already cancelled, return the existing data
             return self._cancel_response(transaction)
 
-        # Use the mark_as_cancelled method to properly store the reason
-        transaction.mark_as_cancelled(reason=reason)
+        if transaction.state == PaymentTransaction.INITIATING:
+            transaction.mark_as_cancelled_during_init(reason=reason)
+
+        else:
+            # Use the mark_as_cancelled method to properly store the reason
+            transaction.mark_as_cancelled(reason=reason)
 
         # Call the event method
         self.cancelled_payment(params, transaction)
@@ -580,27 +591,33 @@ class ClickWebhook(View):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
 
-        # Try to get the account model from settings
-        # Get the account model from settings
-        account_model_path = getattr(
-            settings, 'CLICK_ACCOUNT_MODEL', 'django.contrib.auth.models.User'
+        paytechuz_settings = getattr(settings, 'PAYTECHUZ', {})
+        click_settings = paytechuz_settings.get('CLICK', {})
+        
+        account_model_path = (
+            click_settings.get('ACCOUNT_MODEL') or 
+            getattr(settings, 'CLICK_ACCOUNT_MODEL')
         )
         try:
             self.account_model = import_string(account_model_path)
         except ImportError:
-            # If the model is not found, log an error and raise an exception
             logger.error(
-                "Could not import %s. Check CLICK_ACCOUNT_MODEL setting.",
+                "Could not import %s. Check PAYTECHUZ.CLICK.ACCOUNT_MODEL setting.",
                 account_model_path
             )
-            raise ImportError(
-                f"Import error: {account_model_path}"
-            ) from None
+            raise ImportError(f"Import error: {account_model_path}") from None
 
-        self.service_id = getattr(settings, 'CLICK_SERVICE_ID', '')
-        self.secret_key = getattr(settings, 'CLICK_SECRET_KEY', '')
-        self.commission_percent = getattr(
-            settings, 'CLICK_COMMISSION_PERCENT', 0.0
+        self.service_id = (
+            click_settings.get('SERVICE_ID') or 
+            getattr(settings, 'CLICK_SERVICE_ID', '')
+        )
+        self.secret_key = (
+            click_settings.get('SECRET_KEY') or 
+            getattr(settings, 'CLICK_SECRET_KEY', '')
+        )
+        self.commission_percent = (
+            click_settings.get('COMMISSION_PERCENT') or 
+            getattr(settings, 'CLICK_COMMISSION_PERCENT', 0.0)
         )
 
     def post(self, request, **_):
@@ -773,30 +790,37 @@ class ClickWebhook(View):
         """
         Check authentication using signature.
         """
-        if str(params.get('service_id')) != self.service_id:
+        # Check if service_id and secret_key are set
+        if not self.service_id or not self.secret_key:
+            raise PermissionDenied("Missing required settings: service_id or secret_key")
+
+        if str(params.get("service_id")) != self.service_id:
             raise PermissionDenied("Invalid service ID")
 
-        # Check signature if secret key is provided
-        if self.secret_key:
-            sign_string = params.get('sign_string')
-            sign_time = params.get('sign_time')
+        sign_string = params.get("sign_string")
+        sign_time = params.get("sign_time")
 
-            if not sign_string or not sign_time:
-                raise PermissionDenied("Missing signature parameters")
+        if not sign_string or not sign_time:
+            raise PermissionDenied("Missing signature parameters")
 
-            # Create string to sign
-            to_sign = (
-                f"{params.get('click_trans_id')}{params.get('service_id')}"
-            )
-            to_sign += f"{self.secret_key}{params.get('merchant_trans_id')}"
-            to_sign += f"{params.get('amount')}{params.get('action')}"
-            to_sign += f"{sign_time}"
+        # Prepare signature components; note merchant_prepare_id added compared to your original
+        text_parts = [
+            str(params.get("click_trans_id") or ""),
+            str(params.get("service_id") or ""),
+            str(self.secret_key or ""),
+            str(params.get("merchant_trans_id") or ""),
+            str(params.get("merchant_prepare_id") or ""),  # added here
+            str(params.get("amount") or ""),
+            str(params.get("action") or ""),
+            str(sign_time)
+        ]
 
-            # Generate signature
-            signature = hashlib.md5(to_sign.encode('utf-8')).hexdigest()
+        # Calculate hash
+        calculated_hash = hashlib.md5("".join(text_parts).encode("utf-8")).hexdigest()
+
+        if calculated_hash != sign_string:
+            raise PermissionDenied("Invalid signature")
 
-            if signature != sign_string:
-                raise PermissionDenied("Invalid signature")
 
     def _find_account(self, merchant_trans_id):
         """
@@ -878,3 +902,134 @@ class ClickWebhook(View):
             transaction: Transaction object
         """
         # This method is meant to be overridden by subclasses
+
+
+class AtmosWebhook(View):
+    """
+    Base Atmos webhook handler for Django.
+
+    This class handles webhook requests from the Atmos payment system.
+    You can extend this class and override the event methods to customize
+    the behavior.
+    """
+
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
+
+        paytechuz_settings = getattr(settings, 'PAYTECHUZ', {})
+        atmos_settings = paytechuz_settings.get('ATMOS', {})
+
+        self.api_key = (
+            atmos_settings.get('API_KEY') or
+            getattr(settings, 'ATMOS_API_KEY', '')
+        )
+
+        account_model_path = (
+            atmos_settings.get('ACCOUNT_MODEL') or
+            getattr(settings, 'ATMOS_ACCOUNT_MODEL', 'django.contrib.auth.models.User')
+        )
+        try:
+            self.account_model = import_string(account_model_path)
+        except ImportError:
+            logger.error(
+                "Could not import %s. Check PAYTECHUZ.ATMOS.ACCOUNT_MODEL setting.",
+                account_model_path
+            )
+            raise ImportError(f"Import error: {account_model_path}") from None
+
+        self.account_field = (
+            atmos_settings.get('ACCOUNT_FIELD') or
+            getattr(settings, 'ATMOS_ACCOUNT_FIELD', 'id')
+        )
+
+    def post(self, request, **_):
+        """
+        Handle POST requests from Atmos.
+        """
+        try:
+            # Parse request data
+            data = json.loads(request.body.decode('utf-8'))
+
+            # Verify signature
+            received_signature = data.get('sign', '')
+            if not self._verify_signature(data, received_signature):
+                logger.error("Invalid webhook signature")
+                return JsonResponse({
+                    'status': 0,
+                    'message': 'Invalid signature'
+                }, status=400)
+
+            # Extract webhook data
+            store_id = data.get('store_id')
+            transaction_id = data.get('transaction_id')
+            amount = data.get('amount')
+            invoice = data.get('invoice')
+            transaction_time = data.get('transaction_time')
+
+            logger.info(f"Webhook received for transaction {transaction_id}, "
+                       f"invoice {invoice}, amount {amount}")
+
+            # Find transaction by invoice (account)
+            try:
+                transaction = PaymentTransaction._default_manager.get(
+                    gateway=PaymentTransaction.ATMOS,
+                    account_id=invoice
+                )
+
+                # Update transaction with webhook data
+                transaction.transaction_id = transaction_id
+                transaction.mark_as_paid()
+
+                # Call the event method
+                self.successfully_payment(data, transaction)
+
+                return JsonResponse({
+                    'status': 1,
+                    'message': 'Успешно'
+                })
+
+            except PaymentTransaction.DoesNotExist:
+                logger.error(f"Transaction not found for invoice: {invoice}")
+                return JsonResponse({
+                    'status': 0,
+                    'message': f'Transaction not found for invoice: {invoice}'
+                }, status=400)
+
+        except Exception as e:
+            logger.exception("Unexpected error in Atmos webhook: %s", e)
+            return JsonResponse({
+                'status': 0,
+                'message': f'Error: {str(e)}'
+            }, status=500)
+
+    def _verify_signature(self, webhook_data, received_signature):
+        """
+        Verify webhook signature from Atmos.
+        """
+        # Extract data from webhook
+        store_id = str(webhook_data.get('store_id', ''))
+        transaction_id = str(webhook_data.get('transaction_id', ''))
+        invoice = str(webhook_data.get('invoice', ''))
+        amount = str(webhook_data.get('amount', ''))
+
+        # Create signature string: store_id+transaction_id+invoice+amount+api_key
+        signature_string = f"{store_id}{transaction_id}{invoice}{amount}{self.api_key}"
+
+        # Generate MD5 hash
+        calculated_signature = hashlib.md5(
+            signature_string.encode('utf-8')).hexdigest()
+
+        # Compare signatures
+        return calculated_signature == received_signature
+
+    # Event methods that can be overridden by subclasses
+
+    def successfully_payment(self, params, transaction):
+        """
+        Called when a payment is successful.
+
+        Args:
+            params: Request parameters
+            transaction: Transaction object
+        """
+        # This method is meant to be overridden by subclasses
